PRO convert_lc, filename
  ;Converts NStED periodogram tool phased light-curve output files to format
  ; suitable for input to Binary Maker 3.
  ;JvE, July 2010
  ;
  ;INPUTS:
  ;   FILENAME -- string containing filename of data output from periodogram tool
  ;
  ;OUTPUTS:
  ;   Converted file with the same name as the input file but with '.rnm' appended,
  ;     as for Binary Maker input files
  ;
  ;CALLS:
  ;   writecol

  outputsuffix='.nrm'
  
  print, 'Reading: '+filename
  readcol, filename,mjd,flux,phase,format='(d,d,d)', /silent
  good = where(phase lt 1.0 and phase ge 0.0)
  goodflux = flux[good]     ;Trim off repetitions
  goodphase = phase[good]
  
  dummy = min(goodflux, wheremin)
  phaseatmin = goodphase[wheremin]
  
  
  ;Shift phase so that zero is at min. flux point.
  phase_shifted = (goodphase - phaseatmin + 1.0) mod 1.0
  sortedindices = sort(phase_shifted)
  phase_out = phase_shifted[sortedindices]
  flux_out = goodflux[sortedindices]/max(goodflux[sortedindices])     ;Sort and normalise to max. flux.
  
  print, 'Writing: '+filename+outputsuffix
  writecol, filename+outputsuffix, phase_out, flux_out, fmt='(d,d)'
  print, 'Done.'
END

